from setuptools import setup

setup(
    name="quakex",
    version="0.1.2",
    long_description="",
    long_description_content_type="text/markdown",
    packages=["quakex"],
    install_requires=["numpy",  "h5py", "matplotlib", "pandas"],
)
